<?php

/*
Copyright 2008 Simon JY Antoun & Murdoch J Gabbay
Copyright 2010 Andrew Dodd & Murdoch J Gabbay
andrewdodd13@gmail.com

This file is part of Publications Map.

Publications Map is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Publications Map is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See  the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Publications Map.  If not, see <http://www.gnu.org/licenses/>.
*/

/* You may edit the HTML and PHP of this file as you see fit. The logic is only
 * provided as an example
 */

/* A small function for decoding Simon's encoded HTML */
function parseText($string)
{
	return preg_replace(array("/{/", "/}/"), array("<", ">"), $string);
}

?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">

<!-- Web Page Design by James Koster - http://www.jameskoster.co.uk -->

<head>
	<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
	<title>Academic journal and conference papers on nominal techniques by Murdoch Gabbay (Jamie)</title>
	<link href="style.css" rel="stylesheet" type="text/css" />
</head>

<body>
<a name="top" id="top"></a>
<div id="menu">
	<a href="./index.html#top">Main page</a>				  
	<a href="./index.html#talks">Talks</a>			
	<a href="./personal.html">More about me</a>				 
	<a href="./index.html#links">Site map</a>				 
</div>

<div id="header">
	<h1>Papers</h1>
	<h2>Murdoch James Gabbay</h2>
</div>

<div id="narrowcontent">
	<div class="introduction">
Scroll down for pdf, djvu
<a href="http://www.djvuzone.org/download/index.html">
(what's that?)</a>, and BibTeX of my papers.
Click above for a flash-based graphical presentation of my papers.
<br />
<a href="http://www.informatik.uni-trier.de/~ley/db/indices/a-tree/g/Gabbay:Murdoch.html">Murdoch J. Gabbay on DBLP</a> (not always up-to-date).
	</div>

<!-- Beginning of non-static content -->
<?php

/* Read the data from the XML into a structure Smarty can use */
$xmldata = simplexml_load_file('data.xml');

if(!$xmldata)
	die("Oh something has gone terribly wrong!");

/* Build a mapping of all the types */
$type_map = array();

foreach($xmldata->types->type as $type_node)
{
	$internal = (string)$type_node[0];
	$visible = $type_node->attributes();
	$visible = (string)$visible['listname'][0];
	
	if(preg_match('/[^(]+\(([^)]+)\)/', $visible, $matches))
	{
		$visible = $matches[1];
	}

	$type_map[$internal] = $visible;
}

$node_data = array();

/* Build a list of all the nodes */
foreach($xmldata->node as $xml_node)
{
	$type = $type_map[(string)$xml_node[0]->type];
	if(!array_key_exists($type, $node_data))
		$node_data[$type] = array();

	if($xml_node[0]->visibleWeb != "false")
		array_push($node_data[$type], $xml_node[0]);
}

function sort_fn($a, $b)
{
	if((int)$a->year == (int)$b->year)
	{
		if((int)$a->month == (int)$b->month)
			return 0;
			
		return ((int)$a->month > (int)$b->month ? -1 : 1);
	}

	return ((int)$a->year > (int)$b->year) ? -1 : 1;	
}

/* Sort the nodes by year then month */
foreach($node_data as $key => $category_elements)
{
	usort($category_elements, "sort_fn");
	$node_data[$key] = $category_elements;
}

foreach($node_data as $key => $category)
{
	echo "<a name='{$key}'></a>";
	echo '<h1 style="margin-top: 5ex; margin-bottom: 3ex;">';
	echo '<a href="#top">top, </a>';

	$titlestring = ""; $span_last = false;
	foreach(array_keys($node_data) as $acategory)
	{
		if ($key == $acategory)
		{
			$titlestring .= "<span class='bigh1font'>{$acategory}, </span>";
			$span_last = true;
		}
		else
		{
			$titlestring .= "<a href='#{$acategory}'>" . strtolower($acategory) . ", </a>";
			$span_last = false;
		}
	}
	
	$titlestring = substr($titlestring, 0, ($span_last ? -9 : -6));
	
	echo $titlestring . ($span_last ? "</span>" : "</a>") . ".</h1>";
	
	echo '<dl class="spaceddd">';
	foreach ($category as $node)
	{
		echo '<dt>';
		echo "<a id='{$node->bibtex}'></a>";
		echo "<a href='{$node->file}'>";
		echo "<span class='titles'>{$node->title}</span>";
		echo "<span class='lamcctag'>{$node->author}, {$node->ref}</span>";
		echo '</a>';
		echo '</dt>';
			
		echo '<dd>';
		echo '<div class="papercomment">';
		echo parseText($node->notes);
		echo '</div>';
		echo '<div class="fr">';
		echo "{$node->bibtex}&nbsp;";
		echo "[<a href='{$node->file}'>pdf</a>]";
		
		$djvulink = substr($node->file, 0, -3) . "djvu";
		echo "[<a href='{$djvulink}'>djvu</a>]";
		echo "[<a href='biburl here'>bib</a>]";
		echo "[<a href='{$node->doi}'>DOI</a>]";
		echo '</div>';
		echo '</dd>';
	}
	
	echo '</dl>';
}

?>
<!-- End non-static content -->
</div>

<div id="footlinks">
	<ul>
		<li><a href="#top">Top</a></li>
		<li><a href="./index.html#top">Main page</a></li>
	</ul>
</div>

<div id="footer">
Page by Murdoch James Gabbay.<br />
Page design adapted from <a href="http://www.oswd.org/files/designs/2087/plain/">Plain v1.0</a> by <a href="http://www.sixshootermedia.com/jk10/">James Koster</a>, found thanks to <a href="http://www.oswd.org/">OSWD</a>.  <br/> All errors due to myself; please <a href="./index.html#contact">contact me</a> if you find them.    
</div>
</body>
</html>